==> owncloud-5.0.9.tgz: owncloud/apps/bookmarks/l10n/de.php <==
<?php $TRANSLATIONS = array(
"No file provided for import" => "Es wurde keine Datei zum Import zur Verfügung gestellt",
"Unsupported file type for import" => "Dateityp wird für den Import nicht unterstützt",
"Bookmarks" => "Lesezeichen",
"Tags" => "Tags",
"Filter by tag" => "Filtern nach Schlagwort",
"Edit bookmark" => "Lesezeichen bearbeiten",
"Are you sure you want to remove this tag from every entry?" => "Soll dieses Schlagwort wirklich von allen Einträgen entfernt werden?",
"Warning" => "Warnung",
"Import error" => "Import Fehler",
"Import completed successfully." => "Der Import wurde erfolgreich abgeschlossen.",
"Uploading..." => "Lade hoch ...",
"Bookm." => "Lesez.",
"Add a bookmark" => "Ein Lesezeichen hinzufügen",
"Close" => "Schließen",
"The title of the page" => "Der Titel der Seite",
"The address of the page" => "Die Adresse der Seite",
"Description of the page" => "Die Beschreibung der Seite",
"Save" => "Speichern",
"Delete" => "Löschen",
"Edit" => "Bearbeiten",
"Cancel" => "Abbrechen",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Ziehe dies zu Deinen Browser-Lesezeichen und klicke darauf, wenn Du eine Website schnell den Lesezeichen hinzufügen willst.",
"Read later" => "Später lesen",
"Address" => "Adresse",
"Add" => "Hinzufügen",
"Related Tags" => "Verwandte Schlagworte",
"Settings" => "Einstellungen",
"You have no bookmarks" => "Du hast keine Lesezeichen",
"You can also try to import a bookmark file" => "Du kannst auch versuchen eine Lesezeichendatei zu importieren.",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Export & Import",
"Export" => "Exportieren",
"Import" => "Importieren"
);

==> owncloud-7.0.4.tgz: owncloud/apps/bookmarks/l10n/de.php <==
<?php
$TRANSLATIONS = array(
"No file provided for import" => "Es wurde keine Datei zum Import zur Verfügung gestellt",
"Unsupported file type for import" => "Dateityp wird für den Import nicht unterstützt",
"Bookmarks" => "Lesezeichen",
"Tags" => "Tags",
"Filter by tag" => "Filtern nach Schlagwort",
"Edit bookmark" => "Lesezeichen bearbeiten",
"Are you sure you want to remove this tag from every entry?" => "Soll dieses Schlagwort wirklich von allen Einträgen entfernt werden?",
"Warning" => "Warnung",
"Import error" => "Import Fehler",
"Import completed successfully." => "Der Import wurde erfolgreich abgeschlossen.",
"Uploading..." => "Lade hoch ...",
"Bookm." => "Lesez.",
"Add a bookmark" => "Ein Lesezeichen hinzufügen",
"Close" => "Schließen",
"The title of the page" => "Der Titel der Seite",
"The address of the page" => "Die Adresse der Seite",
"Description of the page" => "Die Beschreibung der Seite",
"Save" => "Speichern",
"Delete" => "Löschen",
"Edit" => "Bearbeiten",
"Cancel" => "Abbrechen",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Ziehe dies zu Deinen Browser-Lesezeichen und klicke darauf, wenn Du eine Website schnell den Lesezeichen hinzufügen willst.",
"Add to ownCloud" => "Zu ownCloud hinzufügen",
"Address" => "Adresse",
"Add" => "Hinzufügen",
"Related Tags" => "Verwandte Schlagworte",
"Settings" => "Einstellungen",
"You have no bookmarks" => "Du hast keine Lesezeichen",
"You can also try to import a bookmark file" => "Du kannst auch versuchen eine Lesezeichendatei zu importieren.",
"Bookmarklet" => "Bookmarklet",
"Export & Import" => "Export & Import",
"Export" => "Exportieren",
"Import" => "Importieren"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
